/*
******************************************************************************

   Edemo implementation for X target - initialization.

   Authors:	1999-2000 Marcus Sundberg	[marcus@ggi-project.org]
  
   This code is placed in the public domain and may be used freely for any
   purpose.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include "xedemo.h"


static int GGIopen(ggi_visual *vis, struct ggi_dlhandle *dlh,
		   const char *args, void *argptr, uint32 *dlret)
{
	printf("LibEDEMO: GGIopen(%p, %p, %s, %p, %p) called for X_edemo sublib\n",
	       vis, dlh, args ? args : "(NULL)", argptr, dlret);

	XEDEMO_PRIV(vis) = malloc(sizeof(struct xedemo_priv));
	if (XEDEMO_PRIV(vis) == NULL) return GGI_ENOMEM;

	LIBGGI_EDEMOEXT(vis)->function1 = EDEMO_X_function1;
	LIBGGI_EDEMOEXT(vis)->function2 = EDEMO_X_function2;

	*dlret = (GGI_DL_EXTENSION | GGI_DL_OPDISPLAY);
	return 0;
}	/* GGIopen */


static int GGIclose(ggi_visual *vis, struct ggi_dlhandle *dlh)
{
	printf("LibEDEMO: GGIclose(%p, %p) called for X_edemo sublib\n",
	       vis, dlh);

	free(XEDEMO_PRIV(vis));

	XEDEMO_PRIV(vis) = NULL;

	return 0;
}	/* GGIclose */


int EDEMOdl_X_edemo(int func, void **funcptr)
{
	switch (func) {
	case GGIFUNC_open:
		*funcptr = GGIopen;
		return 0;
	case GGIFUNC_exit:
		*funcptr = NULL;
		return 0;
	case GGIFUNC_close:
		*funcptr = GGIclose;
		return 0;
	default:
		*funcptr = NULL;
	}	/* switch */

	return GGI_ENOTFOUND;
}	/* EDEMOdl_X_edemo */


/* This should be included by exactly _one_ file in each sublib. */
#include <ggi/internal/ggidlinit.h>
